<?xml version="1.0" ?><!DOCTYPE TS><TS language="it_IT" version="2.0">
<context>
    <name>Badges</name>
    <message>
        <location filename="../qml/pages/Badges.qml" line="18"/>
        <source>BADGES</source>
        <translation>BADGE</translation>
    </message>
</context>
<context>
    <name>Checkin</name>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="18"/>
        <source>CHECK-IN DETAILS</source>
        <translation>DETTAGLI SUL CHECK-IN</translation>
    </message>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="223"/>
        <source>TOTAL POINTS</source>
        <translation>PUNTI TOTALI</translation>
    </message>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="261"/>
        <source>EARNED BADGES</source>
        <translation>BADGE OTTENUTI</translation>
    </message>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="283"/>
        <source>COMMENTS</source>
        <translation>COMMENTI</translation>
    </message>
</context>
<context>
    <name>CheckinDialog</name>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="22"/>
        <source>NEW CHECK-IN</source>
        <translation>NUOVO CHECK-IN</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="48"/>
        <source>CHECK IN</source>
        <translation>CHECK-IN</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="57"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="100"/>
        <source>Whats on your mind?</source>
        <translation>Che ti passa per la testa?</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="129"/>
        <source>Sharing options</source>
        <translation>Opzioni di condivisione</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="133"/>
        <source>Share with Friends</source>
        <translation>Condividi con gli Amici</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="141"/>
        <source>Post to Facebook</source>
        <translation>Condividi su Facebook</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="149"/>
        <source>Post to Twitter</source>
        <translation>Condividi su Twitter</translation>
    </message>
</context>
<context>
    <name>CheckinHistory</name>
    <message>
        <location filename="../qml/pages/CheckinHistory.qml" line="24"/>
        <source>CHECK-IN HISTORY</source>
        <translation>CRONOLOGIA CHECK-IN</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinHistory.qml" line="64"/>
        <source>Load More</source>
        <translation>Carica altro</translation>
    </message>
</context>
<context>
    <name>CommentDialog</name>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="26"/>
        <source>What is on your mind?</source>
        <translation>Che ti passa per la testa?</translation>
    </message>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="38"/>
        <source>New awesome comment</source>
        <translation>Nuovo incredibile commento</translation>
    </message>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="69"/>
        <source>Comment!</source>
        <translation>Commenta!</translation>
    </message>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="77"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>DebugSubmit</name>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="18"/>
        <source>DEBUG SUBMIT</source>
        <translation>INVIA DEBUG</translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="34"/>
        <source>Thank you for submit!&lt;br&gt;This will be implemented soon!</source>
        <translation>Grazie per aver inviato! &lt;br&gt;Questo verrà implementato presto!</translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="53"/>
        <source>SUBMIT</source>
        <translation>INVIA</translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="61"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="92"/>
        <source>You can help me with Nelisquare development by submitting debug info.

The following information are going to be submitted:</source>
        <translation>Puoi aiutarmi nello sviluppo di Nelisquare inviando informazioni di debug.

Le seguenti informazioni stanno per essere inviate:</translation>
    </message>
</context>
<context>
    <name>DebugWidget</name>
    <message>
        <location filename="../qml/components/DebugWidget.qml" line="14"/>
        <source>Unknown %1 event!</source>
        <translation>Evento %1 sconosciuto</translation>
    </message>
    <message>
        <location filename="../qml/components/DebugWidget.qml" line="47"/>
        <source>This event type is unknown.
You can help with resolution.</source>
        <translation>Questo evento è di tipo sconosciuto.
Puoi aiutare fornendo dettagli.</translation>
    </message>
</context>
<context>
    <name>FriendsFeed</name>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="43"/>
        <source>FRIENDS FEED</source>
        <translation>ATTIVITÀ</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="221"/>
        <source>RECENT</source>
        <translation>RECENTI</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="234"/>
        <source>NEARBY</source>
        <translation>NELLE VICINANZE</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="255"/>
        <source>Load More</source>
        <translation>Carica altro</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="402"/>
        <source>Sorry, Pages are not supported yet :(</source>
        <translation>Spiacente, le Pagine non sono ancora supportate :(</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="472"/>
        <source>Sorry, no lists support yet :(</source>
        <translation>Spiacente, le liste non sono ancora supportate :(</translation>
    </message>
</context>
<context>
    <name>LeaderBoard</name>
    <message>
        <location filename="../qml/pages/LeaderBoard.qml" line="19"/>
        <source>YOU ARE #</source>
        <translation>SEI IL #</translation>
    </message>
    <message>
        <location filename="../qml/pages/LeaderBoard.qml" line="63"/>
        <source>&lt;b&gt;%1 points&lt;/b&gt; %2 checkins</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LikeBox</name>
    <message>
        <location filename="../qml/components/LikeBox.qml" line="33"/>
        <source>USER LIKES</source>
        <translation>È PIACIUTO A</translation>
    </message>
</context>
<context>
    <name>ListViewEx</name>
    <message>
        <location filename="../qml/components/ListViewEx.qml" line="9"/>
        <source>Pull and hold to refresh...</source>
        <translation>Tira verso il basso per aggiornare...</translation>
    </message>
    <message>
        <location filename="../qml/components/ListViewEx.qml" line="10"/>
        <source>Release to refresh...</source>
        <translation>Rilascia per aggiornare...</translation>
    </message>
</context>
<context>
    <name>Login24sq</name>
    <message>
        <location filename="../qml/pages/Login24sq.qml" line="42"/>
        <source>Sign In to Foursquare</source>
        <translation>Accedi a Foursquare</translation>
    </message>
</context>
<context>
    <name>Mayorships</name>
    <message>
        <location filename="../qml/pages/Mayorships.qml" line="19"/>
        <source>MAYORSHIPS</source>
        <translation>MAYORSHIP</translation>
    </message>
</context>
<context>
    <name>NotificationDialog</name>
    <message>
        <location filename="../qml/components/NotificationDialog.qml" line="36"/>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>Notifications</name>
    <message>
        <location filename="../qml/pages/Notifications.qml" line="24"/>
        <source>NOTIFICATIONS</source>
        <translation>NOTIFICHE</translation>
    </message>
    <message>
        <location filename="../qml/pages/Notifications.qml" line="51"/>
        <source>Mark all as read</source>
        <translation>Segna tutte come lette</translation>
    </message>
    <message>
        <location filename="../qml/pages/Notifications.qml" line="58"/>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
</context>
<context>
    <name>PageWrapper</name>
    <message>
        <location filename="../qml/components/PageWrapper.qml" line="88"/>
        <source>Check updates</source>
        <translation>Controlla aggiornamenti</translation>
    </message>
    <message>
        <location filename="../qml/components/PageWrapper.qml" line="94"/>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <location filename="../qml/components/PageWrapper.qml" line="100"/>
        <source>Exit</source>
        <translation>Esci</translation>
    </message>
</context>
<context>
    <name>Photo</name>
    <message>
        <location filename="../qml/pages/Photo.qml" line="20"/>
        <source>PHOTO</source>
        <translation>FOTO</translation>
    </message>
</context>
<context>
    <name>PhotoAdd</name>
    <message>
        <location filename="../qml/pages/PhotoAdd.qml" line="18"/>
        <source>Select photo for upload</source>
        <translation>Scegli la foto da caricare</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoAdd.qml" line="56"/>
        <source>Error uploading photo!</source>
        <translation>Errore nel caricare la foto!</translation>
    </message>
</context>
<context>
    <name>PhotoShareDialog</name>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="20"/>
        <source>PHOTO UPLOAD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="36"/>
        <source>UPLOAD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="86"/>
        <source>Sharing options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="90"/>
        <source>Public</source>
        <translation>Pubblico</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="97"/>
        <source>Post to Facebook</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="104"/>
        <source>Post to Twitter</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="48"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>PhotosBox</name>
    <message>
        <location filename="../qml/components/PhotosBox.qml" line="8"/>
        <source>PHOTOS</source>
        <translation>FOTO</translation>
    </message>
</context>
<context>
    <name>PhotosGallery</name>
    <message>
        <location filename="../qml/pages/PhotosGallery.qml" line="13"/>
        <source>VENUE PHOTOS</source>
        <translation>FOTO DEL LUOGO</translation>
    </message>
</context>
<context>
    <name>SettingSlider</name>
    <message>
        <location filename="../qml/components/SettingSlider.qml" line="50"/>
        <source>Off</source>
        <translation>Disattiva</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../qml/pages/Settings.qml" line="13"/>
        <source>updating...</source>
        <translation>aggiornamento...</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="21"/>
        <source>SETTINGS</source>
        <translation>IMPOSTAZIONI</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="53"/>
        <source>2012-2013 Basil Semuonov</source>
        <translation>2012-2013 Basil Semuonov</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="54"/>
        <source>Idea by Tommi Laukkanen</source>
        <translation>Idea di Tommi Laukkanen</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="55"/>
        <source>Shout out to @knobtviker</source>
        <translation>Fai un fischio a @knobtviker</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="56"/>
        <source>Design by Kim Venetvirta</source>
        <translation>Design di Kim Venetvirta</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="57"/>
        <source>If any problems, tweet @basil_s</source>
        <translation>Se hai un qualsiasi problema, twitta a @basil_s</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="58"/>
        <source>Version</source>
        <translation>Versione</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="60"/>
        <source>Build</source>
        <translation>Build</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="62"/>
        <source>Powered by Foursquare</source>
        <translation>Powered by Foursquare</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="64"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="70"/>
        <location filename="../qml/pages/Settings.qml" line="115"/>
        <source>Reset settings</source>
        <translation>Azzera impostazioni</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="71"/>
        <source>This action will erase all data including auth token, application settings and cache.</source>
        <translation>Questa azione cancellerà tutti i dati, inclusi il token di autorizzazione, le impostazioni dell&apos;applicazione e la cache.</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="72"/>
        <source>Yes, clear the data</source>
        <translation>Sì, cancella i dati</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="73"/>
        <source>No, thanks</source>
        <translation>No, grazie</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="81"/>
        <source>Language</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="109"/>
        <source>Notifications</source>
        <translation>Notifiche</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="161"/>
        <source>UPDATES CHECK</source>
        <translation>CONTROLLO AGGIORNAMENTI</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="186"/>
        <source>None</source>
        <translation>Nessuno</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="192"/>
        <source>Stable</source>
        <translation>Stabile</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="197"/>
        <source>Beta</source>
        <translation>Beta</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="203"/>
        <source>Alpha</source>
        <translation>Alpha</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="209"/>
        <source>INTERVALS</source>
        <translation>INTERVALLI</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="213"/>
        <source>GPS Unlock timeout</source>
        <translation>Tempo di sblocco del GPS</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="214"/>
        <source>Instant</source>
        <translation>Istantaneo</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="214"/>
        <source>%1 secs(s)</source>
        <translation>%1 secwazapp/language/it/</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="214"/>
        <location filename="../qml/pages/Settings.qml" line="223"/>
        <source>Disabled</source>
        <translation>Disattivato</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="222"/>
        <source>Feed autoupdate time</source>
        <translation>Aggiornamento attività</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="223"/>
        <source>Off</source>
        <translation>Disattiva</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="223"/>
        <source>%1 min(s)</source>
        <translation>%1 min</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="231"/>
        <source>PERMISSIONS</source>
        <translation>PERMESSI</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="234"/>
        <source>Allow use of Location Data</source>
        <translation>Permetti l&apos;uso dei dati sulla posizione</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="242"/>
        <source>Always run in background</source>
        <translation>Mantieni in esecuzione in background</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="250"/>
        <source>Enable notifications</source>
        <translation>Attiva notifiche</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="258"/>
        <source>Feed at Home screen</source>
        <translation>Feed nella Schermata Iniziale</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="266"/>
        <source>Push notifications</source>
        <translation>Notifiche push</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="317"/>
        <source>COLOR THEME</source>
        <translation>COLORE TEMA</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="336"/>
        <source>Light</source>
        <translation>Chiaro</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="342"/>
        <source>Dark</source>
        <translation>Scuro</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="348"/>
        <source>SCREEN ORIENTATION</source>
        <translation>ORIENTAMENTO SCHERMO</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="370"/>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="376"/>
        <source>Landscape</source>
        <translation>Orizzontale</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="381"/>
        <source>Portrait</source>
        <translation>Verticale</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="387"/>
        <source>STARTUP PAGE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="409"/>
        <source>Feed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="415"/>
        <source>Venues</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="420"/>
        <source>Self</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="426"/>
        <source>LANGUAGE</source>
        <translation>LINGUA</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="437"/>
        <source>MAP PROVIDER</source>
        <translation>FORNITORE MAPPE</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="460"/>
        <source>Nokia</source>
        <translation>Nokia</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="466"/>
        <source>Google</source>
        <translation>Google</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="471"/>
        <source>OSM</source>
        <translation>OSM</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="489"/>
        <source>IMAGE LOADING</source>
        <translation>CARICAMENTO IMMAGINI</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="508"/>
        <source>All</source>
        <translation>Tutte</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="513"/>
        <source>Cached</source>
        <translation>Nella cache</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="519"/>
        <source>INTEGRATION WITH APPS</source>
        <translation>APP INTEGRATE</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="525"/>
        <source>Download MOLO.ME</source>
        <translation>Scarica MOLO.ME</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="544"/>
        <source>MOLO.ME Photos</source>
        <translation>Foto da MOLO.ME</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="564"/>
        <source>APPLICATION CACHE</source>
        <translation>CACHE DELL&apos;APPLICAZIONE</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="572"/>
        <source>Clear</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="584"/>
        <source>Size: %1</source>
        <translation>Dimensione: %1</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="590"/>
        <source>UI</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="593"/>
        <source>Reload UI</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="599"/>
        <source>AUTHENTICATION</source>
        <translation>AUTENTICAZIONE</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="602"/>
        <source>Reset authentication</source>
        <translation>Azzera autenticazione</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="623"/>
        <source>ACCESS RATE LIMIT</source>
        <translation>LIMITE DI ACCESSO</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="629"/>
        <source>API requests available: %1 / %2</source>
        <translation>Richieste API disponibili: %1 / %2</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="635"/>
        <source>You are low on X-RATE requests</source>
        <translation>Hai poche richieste X-RATE</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="640"/>
        <source>DEBUG</source>
        <translation>DEBUG</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="643"/>
        <source>Enable debug</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="657"/>
        <source>Options will be available soon</source>
        <translation>Le opzioni saranno presto disponibili</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="672"/>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="673"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="674"/>
        <source>Service</source>
        <translation>Servizio</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="675"/>
        <source>Debug</source>
        <translation>Debug</translation>
    </message>
</context>
<context>
    <name>SpecialsList</name>
    <message>
        <location filename="../qml/components/SpecialsList.qml" line="13"/>
        <source>VENUE SPECIALS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/components/SpecialsList.qml" line="31"/>
        <source>Unlocked!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TipDialog</name>
    <message>
        <location filename="../qml/components/TipDialog.qml" line="40"/>
        <source>Write some cool tip here</source>
        <translation>Scrivi un consiglio qui</translation>
    </message>
    <message>
        <location filename="../qml/components/TipDialog.qml" line="71"/>
        <source>ADD</source>
        <translation>AGGIUNGI</translation>
    </message>
    <message>
        <location filename="../qml/components/TipDialog.qml" line="79"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>TipPage</name>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="22"/>
        <source>Usefull tip</source>
        <translation>Consiglio utile</translation>
    </message>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="149"/>
        <source>TIP PHOTO</source>
        <translation>FOTO DEL CONSIGLIO</translation>
    </message>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="171"/>
        <source>Save tip</source>
        <translation>Salva consiglio</translation>
    </message>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="179"/>
        <source>Mark as done</source>
        <translation>Segna come fatto</translation>
    </message>
</context>
<context>
    <name>TipsList</name>
    <message>
        <location filename="../qml/pages/TipsList.qml" line="18"/>
        <source>TIPS LIST</source>
        <translation>LISTA CONSIGLI</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="12"/>
        <source>New update available</source>
        <translation>Nuovo aggiornamento disponibile</translation>
    </message>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="13"/>
        <source>Version: %1&lt;br&gt;Type: %2&lt;br&gt;Build: %3&lt;br&gt;&lt;br&gt;Changelog: &lt;br&gt;%4</source>
        <translation>Versione: %1&lt;br&gt;Tipo: %2&lt;br&gt;Build: %3&lt;br&gt;&lt;br&gt;Changelog: &lt;br&gt;%4</translation>
    </message>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="19"/>
        <source>Update!</source>
        <translation>Aggiornamento!</translation>
    </message>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="20"/>
        <source>No, thanks</source>
        <translation>No, grazie</translation>
    </message>
</context>
<context>
    <name>User</name>
    <message>
        <location filename="../qml/pages/User.qml" line="59"/>
        <source>USER DETAILS</source>
        <translation>DETTAGLI UTENTE</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="270"/>
        <source>Add Friend</source>
        <translation>Aggiungi Amico</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="282"/>
        <source>Approve Friend</source>
        <translation>Approva amicizia</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="289"/>
        <source>Deny friend</source>
        <translation>Nega amicizia</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="301"/>
        <source>Remove Friend</source>
        <translation>Rimuovi Amico</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="314"/>
        <source>&lt;b&gt;SCORES&lt;/b&gt; (LAST 7 DAYS)</source>
        <translation>&lt;br&gt;PUNTEGGI&lt;/b&gt; (ULTIMI 7 GIORNI)</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="319"/>
        <source>BEST SCORE</source>
        <translation>MIGLIOR PUNTEGGIO</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="377"/>
        <source>Badges</source>
        <translation>Badge</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="412"/>
        <source>Checkins</source>
        <translation>Check-in</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="447"/>
        <source>Mayorships</source>
        <translation>Mayorship</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="482"/>
        <source>Friends</source>
        <translation>Amici</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="517"/>
        <source>Photos</source>
        <translation>Foto</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="553"/>
        <source>Tips</source>
        <translation>Consigli</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="569"/>
        <source>YOU ARE #</source>
        <translation>SEI IL #</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="594"/>
        <source>&lt;b&gt;%1 points&lt;/b&gt; %2 checkins</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UsersList</name>
    <message>
        <location filename="../qml/pages/UsersList.qml" line="21"/>
        <source>Loading...</source>
        <translation>Caricamento...</translation>
    </message>
    <message>
        <location filename="../qml/pages/UsersList.qml" line="30"/>
        <source>USER FRIENDS</source>
        <translation>AMICI DELL&apos;UTENTE</translation>
    </message>
    <message>
        <location filename="../qml/pages/UsersList.qml" line="33"/>
        <source>LIKERS LIST</source>
        <translation>LISTA DEI LIKE</translation>
    </message>
</context>
<context>
    <name>Venue</name>
    <message>
        <location filename="../qml/pages/Venue.qml" line="143"/>
        <source>VENUE PHOTOS</source>
        <translation>FOTO DEL LUOGO</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="251"/>
        <source>CHECK-IN HERE!</source>
        <translation>FAI CHECK-IN QUI!</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="273"/>
        <source>Venue doesn&apos;t have mayor yet!</source>
        <translation>Questo luogo ancora non ha un sindaco!</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="274"/>
        <source>is the mayor.</source>
        <translation>è il sindaco.</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="274"/>
        <source>It could be you!</source>
        <translation>Potresti essere tu!</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="275"/>
        <source>%1 checkins</source>
        <translation>%1 check-in</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="317"/>
        <source>BEST TIPS</source>
        <translation>MIGLIORI CONSIGLI</translation>
    </message>
</context>
<context>
    <name>VenueAdd</name>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="91"/>
        <source>Venue name</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>VenueMap</name>
    <message>
        <location filename="../qml/pages/VenueMap.qml" line="186"/>
        <source>GET ROUTE</source>
        <translation>OTTIENI INDICAZIONI</translation>
    </message>
</context>
<context>
    <name>VenuesList</name>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="21"/>
        <source>NEARBY VENUES</source>
        <translation>LUOGHI NELLE VICINANZE</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="67"/>
        <source>GPS signal is fuzzy, cannot get your location</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="96"/>
        <source>Tap to search place...</source>
        <translation>Tocca per cercare un luogo...</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="107"/>
        <source>SEARCH</source>
        <translation>CERCA</translation>
    </message>
</context>
<context>
    <name>Welcome</name>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="29"/>
        <source>Welcome!</source>
        <translation>Benvenuto!</translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="46"/>
        <source>Please, login with Foursquare!</source>
        <translation>Per favore, accedi a Foursquare</translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="53"/>
        <source>Login</source>
        <translation>Accedi</translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="67"/>
        <source>Foursquare privacy policy</source>
        <translation>Informativa sulla privacy di Foursquare</translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="81"/>
        <source>Nelisquare privacy policy</source>
        <translation>Informativa sulla privacy di Nelisquare</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="108"/>
        <source>Location data</source>
        <translation>Dati sulla posizione</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="109"/>
        <source>Nelisquare requires use of user location data. Data is needed to make geo-location services work properly.</source>
        <translation>Nelisquare ha bisogno di utilizzare i dati sulla posizione dell&apos;utente. Questi dati sono necessari per il Chieti funzionamento dei servizi di geo-localizzazione.</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="110"/>
        <source>Allow</source>
        <translation>Permetti</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="111"/>
        <source>Deny</source>
        <translation>Nega</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="123"/>
        <source>Push notifications</source>
        <translation>Notifiche push</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="124"/>
        <source>Incoming push notifications are not supported at this version and are disabled by default.&lt;br/&gt;&lt;br/&gt;You will be promted again when they will be available at future versions.</source>
        <translation>Le notifiche push non sono supportate in questa versione e sono disattivate. &lt;br/&gt;&lt;br/&gt;Ti verrà chiesto se vuoi attivarle quando saranno abilitate in una futura versione.</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="128"/>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="161"/>
        <source>Check updates</source>
        <translation>Controlla aggiornamenti</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="167"/>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="173"/>
        <source>Exit</source>
        <translation>Esci</translation>
    </message>
</context>
</TS>